3.16.1
Fixes
* Fixed optimizations being disabled after including benchmarking headers under MSVC.
* This was introduced in 3.16.0's fix for the deopt implementation for MSVC never being used.
* Fixed Console reporter replacing `\0xFF`s in user-provided strings.
* Added missing `<cassert>` include to `catch_generators_range.hpp`.
Improvements
* Workaround for GCC's quadratic scaling for release builds with number of test cases.
* In practice the improvement is only noticeable with unity builds and/or template product tests.
* Changed how decomposer operators are defined for better compilation times.
* For Catch2's `SelfTest` binary, this provides ~2% build time improvement.
* Changed how decomposer handles stringification for smaller binary sizes.
…
cb2b34fb30
adam
catch2: updated to 3.16.0
3.16.0
Fixes
* Multiple fixes in `catch_discover_tests`:
* Fixed `<target>_TESTS` variable accumulating JSON fragments alongside test names.
* This was introduced during the refactoring in last release.
* Fixed `<target>_TESTS` variable from `catch_discover_tests` not escaping test names to be properly parsed by CMake.
* This means that e.g. test names with semicolons will not be split into multiple partial test names.
* This bug has existed since the first version of the script.
* Fixed `TEST_PREFIX`/`TEST_SUFFIX` args having leading/trailing whitespace stripped.
* Added workaround for Clang 20-21 compile error with `TEMPLATE_PRODUCT_TEST_CASE`
Improvements
* Verbosity option is now handled per reporter.
…
1f12777c1a
adam
catch2: updated to 3.15.3
3.15.3
Fixes
* The JSON reporter's number handling is locale-independent.
* Removed leftover debug message from `catch_discover_tests`
* Fixed typo in the "Could not jump to the Nth element" exception message
Improvements
* `catch_discover_tests` registers tests in deterministic (alphabetical) order.
* `catch_discover_tests` has been rewritten to be massively faster.
* Preparing the actual CTest script is significantly faster.
* Parsing the JSON test array is significantly faster.
* Running without `ADD_TAGS_AS_LABELS` set is 10-15% faster (as opposed to being the same speed)
* The new implementation is about 4x-5x faster, so registering 500 tests now takes ~350ms (down from 1.1s).
* JSON writing is faster
* Small improvement in writing non-string values
…
b742562848
adam
catch2: updated to 3.15.2
3.15.2
Fixes
Fixed --warn InfiniteGenerators triggering even if the generator was limited to specific element via path filtering.
Fixed -Wunused-parameter triggering in -fnoexceptions builds.
Improvements
catch_discover_tests can handle cases where the binary prints out non-Catch2 output due to global constructors
This site uses Google Analytics cookies to count visits and see which pages are read.
No cookie is set until you accept. What is collected